@@ -131,10 +131,9 @@ enum {
     DIAG_SUBSYS_SMS             = 14, /* Wireless Messaging Service */
     DIAG_SUBSYS_CM              = 15, /* Call manager */
     DIAG_SUBSYS_FS              = 19, /* File System (EFS2) */
-    DIAG_SUBSYS_NOVATEL_6500    = 50, /* for Novatel Wireless MSM6500-based devices */
-    DIAG_SUBSYS_LTE             = 68,
+    DIAG_SUBSYS_NW_CONTROL_6500 = 50, /* for Novatel Wireless MSM6500-based devices */
     DIAG_SUBSYS_ZTE             = 101, /* for ZTE EVDO devices */
-    DIAG_SUBSYS_NOVATEL_6800    = 250 /* for Novatel Wireless MSM6800-based devices */
+    DIAG_SUBSYS_NW_CONTROL_6800 = 250 /* for Novatel Wireless MSM6800-based devices */
 };
 
 /* WCDMA subsystem command codes */
@@ -159,18 +158,18 @@ enum {
     DIAG_SUBSYS_CM_STATE_INFO = 0, /* Gets Call Manager state */
 };
 
-/* NOVATEL subsystem command codes (only for Novatel Wireless devices) */
+/* NW_CONTROL subsystem command codes (only for Novatel Wireless devices) */
 enum {
-    DIAG_SUBSYS_NOVATEL_AT_REQUEST     = 3, /* AT commands via diag */
-    DIAG_SUBSYS_NOVATEL_AT_RESPONSE    = 4,
-    DIAG_SUBSYS_NOVATEL_MODEM_SNAPSHOT = 7,
-    DIAG_SUBSYS_NOVATEL_ERI            = 8, /* Extended Roaming Indicator */
-    DIAG_SUBSYS_NOVATEL_PRL            = 12,
+    DIAG_SUBSYS_NW_CONTROL_AT_REQUEST     = 3, /* AT commands via diag */
+    DIAG_SUBSYS_NW_CONTROL_AT_RESPONSE    = 4,
+    DIAG_SUBSYS_NW_CONTROL_MODEM_SNAPSHOT = 7,
+    DIAG_SUBSYS_NW_CONTROL_ERI            = 8, /* Extended Roaming Indicator */
+    DIAG_SUBSYS_NW_CONTROL_PRL            = 12,
 };
 
 enum {
-    DIAG_SUBSYS_NOVATEL_MODEM_SNAPSHOT_TECH_CDMA_EVDO = 7,
-    DIAG_SUBSYS_NOVATEL_MODEM_SNAPSHOT_TECH_WCDMA     = 20,
+    DIAG_SUBSYS_NW_CONTROL_MODEM_SNAPSHOT_TECH_CDMA_EVDO = 7,
+    DIAG_SUBSYS_NW_CONTROL_MODEM_SNAPSHOT_TECH_WCDMA = 20,
 };
 
 enum {
@@ -459,21 +458,21 @@ struct DMCmdEventReportRsp {
 } __attribute__ ((packed));
 typedef struct DMCmdEventReportRsp DMCmdEventReportRsp;
 
-/* DIAG_SUBSYS_NOVATEL_* subsys command */
+/* DIAG_SUBSYS_NW_CONTROL_* subsys command */
 struct DMCmdSubsysNwSnapshotReq {
     DMCmdSubsysHeader hdr;
-    u_int8_t technology;        /* DIAG_SUBSYS_NOVATEL_MODEM_SNAPSHOT_TECH_* */
+    u_int8_t technology;        /* DIAG_SUBSYS_NW_CONTROL_MODEM_SNAPSHOT_TECH_* */
     u_int32_t snapshot_mask;
 } __attribute__ ((packed));
 typedef struct DMCmdSubsysNwSnapshotReq DMCmdSubsysNwSnapshotReq;
 
-/* DIAG_SUBSYS_NOVATEL_MODEM_SNAPSHOT response */
+/* DIAG_SUBSYS_NW_CONTROL_MODEM_SNAPSHOT response */
 struct DMCmdSubsysNwSnapshotRsp {
     DMCmdSubsysHeader hdr;
     u_int8_t response_code;
     u_int32_t bitfield1;
     u_int32_t bitfield2;
-    u_int8_t data[100];     /* DMCmdSubsysNwSnapshotCdma */
+    u_int8_t data[100];
 } __attribute__ ((packed));
 typedef struct DMCmdSubsysNwSnapshotRsp DMCmdSubsysNwSnapshotRsp;
 
@@ -502,27 +501,6 @@ struct DMCmdSubsysNwSnapshotCdma {
 } __attribute__ ((packed));
 typedef struct DMCmdSubsysNwSnapshotCdma DMCmdSubsysNwSnapshotCdma;
 
-/* DIAG_SUBSYS_NOVATEL_MODEM_SNAPSHOT response */
-struct DMCmdSubsysNwEriRsp {
-    DMCmdSubsysHeader hdr;
-    u_int8_t status;
-    u_int16_t error;
-    u_int8_t roam;
-    u_int8_t eri_header[6];
-    u_int8_t eri_call_prompt[38];
-
-    /* Roaming Indicator */
-    u_int8_t indicator_id;
-    u_int8_t icon_id;
-    u_int8_t icon_mode;
-    u_int8_t call_prompt_id;  /* Call Guard? */
-    u_int8_t alert_id;        /* Ringer? */
-    u_int8_t encoding_type;
-    u_int8_t text_len;
-    u_int8_t text[32];
-} __attribute__ ((packed));
-typedef struct DMCmdSubsysNwEriRsp DMCmdSubsysNwEriRsp;
-
 enum {
     DIAG_CMD_LOG_CONFIG_OP_GET_RANGE = 0x01,
     DIAG_CMD_LOG_CONFIG_OP_SET_MASK = 0x03,
