@@ -16,24 +16,28 @@
 #ifndef MM_PORT_H
 #define MM_PORT_H
 
+#include <config.h>
 #include <glib.h>
 #include <glib-object.h>
 
-typedef enum {
+typedef enum { /*< underscore_name=mm_port_subsys >*/
     MM_PORT_SUBSYS_UNKNOWN = 0x0,
     MM_PORT_SUBSYS_TTY,
     MM_PORT_SUBSYS_NET,
+    MM_PORT_SUBSYS_USB,
 
-    MM_PORT_SUBSYS_LAST = MM_PORT_SUBSYS_NET
+    MM_PORT_SUBSYS_LAST = MM_PORT_SUBSYS_USB /*< skip >*/
 } MMPortSubsys;
 
-typedef enum {
+typedef enum { /*< underscore_name=mm_port_type >*/
     MM_PORT_TYPE_UNKNOWN = 0x0,
-    MM_PORT_TYPE_AT,
     MM_PORT_TYPE_IGNORED,
+    MM_PORT_TYPE_NET,
+    MM_PORT_TYPE_AT,
     MM_PORT_TYPE_QCDM,
-
-    MM_PORT_TYPE_LAST = MM_PORT_TYPE_QCDM
+    MM_PORT_TYPE_GPS,
+    MM_PORT_TYPE_QMI,
+    MM_PORT_TYPE_LAST = MM_PORT_TYPE_QMI /*< skip >*/
 } MMPortType;
 
 #define MM_TYPE_PORT            (mm_port_get_type ())
@@ -74,9 +78,4 @@ gboolean     mm_port_get_connected      (MMPort *self);
 
 void         mm_port_set_connected      (MMPort *self, gboolean connected);
 
-const char * mm_port_type_to_name       (MMPortType ptype);
-
-const char * mm_port_subsys_to_name     (MMPortSubsys psubsys);
-
 #endif /* MM_PORT_H */
-
