@@ -19,8 +19,10 @@
 #include <unistd.h>
 #include <string.h>
 
+#include <ModemManager.h>
+#include <mm-errors-types.h>
+
 #include "mm-qcdm-serial-port.h"
-#include "mm-errors.h"
 #include "libqcdm/src/com.h"
 #include "libqcdm/src/utils.h"
 #include "libqcdm/src/errors.h"
@@ -92,7 +94,7 @@ handle_response (MMSerialPort *port,
     /* Get the offset into the buffer of where the QCDM frame starts */
     if (!find_qcdm_start (response, &start)) {
         g_set_error_literal (&dm_error,
-                             MM_MODEM_ERROR, MM_MODEM_ERROR_GENERAL,
+                             MM_CORE_ERROR, MM_CORE_ERROR_FAILED,
                              "Failed to parse QCDM packet.");
         /* Discard the unparsable data */
         used = response->len;
@@ -110,7 +112,7 @@ handle_response (MMSerialPort *port,
                                      &more);
     if (!success) {
         g_set_error_literal (&dm_error,
-                             MM_MODEM_ERROR, MM_MODEM_ERROR_GENERAL,
+                             MM_CORE_ERROR, MM_CORE_ERROR_FAILED,
                              "Failed to unescape QCDM packet.");
         g_byte_array_free (unescaped, TRUE);
         unescaped = NULL;
@@ -143,6 +145,7 @@ void
 mm_qcdm_serial_port_queue_command (MMQcdmSerialPort *self,
                                    GByteArray *command,
                                    guint32 timeout_seconds,
+                                   GCancellable *cancellable,
                                    MMQcdmSerialResponseFn callback,
                                    gpointer user_data)
 {
@@ -155,6 +158,7 @@ mm_qcdm_serial_port_queue_command (MMQcdmSerialPort *self,
                                   command,
                                   TRUE,
                                   timeout_seconds,
+                                  cancellable,
                                   (MMSerialResponseFn) callback,
                                   user_data);
 }
@@ -163,6 +167,7 @@ void
 mm_qcdm_serial_port_queue_command_cached (MMQcdmSerialPort *self,
                                           GByteArray *command,
                                           guint32 timeout_seconds,
+                                          GCancellable *cancellable,
                                           MMQcdmSerialResponseFn callback,
                                           gpointer user_data)
 {
@@ -175,6 +180,7 @@ mm_qcdm_serial_port_queue_command_cached (MMQcdmSerialPort *self,
                                          command,
                                          TRUE,
                                          timeout_seconds,
+                                         cancellable,
                                          (MMSerialResponseFn) callback,
                                          user_data);
 }
@@ -222,7 +228,6 @@ mm_qcdm_serial_port_new (const char *name)
                                               MM_PORT_DEVICE, name,
                                               MM_PORT_SUBSYS, MM_PORT_SUBSYS_TTY,
                                               MM_PORT_TYPE, MM_PORT_TYPE_QCDM,
-                                              MM_SERIAL_PORT_SEND_DELAY, (guint64) 0,
                                               NULL));
 }
 
@@ -238,7 +243,6 @@ mm_qcdm_serial_port_new_fd (int fd)
                                               MM_PORT_SUBSYS, MM_PORT_SUBSYS_TTY,
                                               MM_PORT_TYPE, MM_PORT_TYPE_QCDM,
                                               MM_SERIAL_PORT_FD, fd,
-                                              MM_SERIAL_PORT_SEND_DELAY, (guint64) 0,
                                               NULL));
     g_free (name);
     return port;
