@@ -28,11 +28,14 @@
 #include <string.h>
 #include <linux/serial.h>
 
+#include <ModemManager.h>
+#include <mm-errors-types.h>
+
 #include "mm-serial-port.h"
-#include "mm-errors.h"
 #include "mm-log.h"
 
 static gboolean mm_serial_port_queue_process (gpointer data);
+static void mm_serial_port_close_force (MMSerialPort *self);
 
 G_DEFINE_TYPE (MMSerialPort, mm_serial_port, MM_TYPE_PORT)
 
@@ -66,6 +69,7 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 typedef struct {
     guint32 open_count;
+    gboolean forced_close;
     int fd;
     GHashTable *reply_cache;
     GIOChannel *channel;
@@ -87,6 +91,9 @@ typedef struct {
     guint watch_id;
     guint timeout_id;
 
+    GCancellable *cancellable;
+    gulong cancellable_id;
+
     guint n_consecutive_timeouts;
 
     guint flash_id;
@@ -103,6 +110,7 @@ typedef struct {
     gpointer user_data;
     guint32 timeout;
     gboolean cached;
+    GCancellable *cancellable;
 } MMQueueData;
 
 #if 0
@@ -176,8 +184,8 @@ mm_serial_port_print_config (MMSerialPort *port, const char *detail)
 
     err = tcgetattr (priv->fd, &stbuf);
     if (err) {
-        g_warning ("*** %s (%s): (%s) tcgetattr() error %d",
-                   __func__, detail, mm_port_get_device (MM_PORT (port)), errno);
+        mm_warn ("*** %s (%s): (%s) tcgetattr() error %d",
+                 __func__, detail, mm_port_get_device (MM_PORT (port)), errno);
         return;
     }
 
@@ -243,7 +251,7 @@ parse_baudrate (guint i)
         speed = B460800;
         break;
     default:
-        g_warning ("Invalid baudrate '%d'", i);
+        mm_warn ("Invalid baudrate '%d'", i);
         speed = B9600;
     }
 
@@ -269,7 +277,7 @@ parse_bits (guint i)
         bits = CS8;
         break;
     default:
-        g_warning ("Invalid bits (%d). Valid values are 5, 6, 7, 8.", i);
+        mm_warn ("Invalid bits (%d). Valid values are 5, 6, 7, 8.", i);
         bits = CS8;
     }
 
@@ -295,7 +303,7 @@ parse_parity (char c)
         parity = PARENB | PARODD;
         break;
     default:
-        g_warning ("Invalid parity (%c). Valid values are n, e, o", c);
+        mm_warn ("Invalid parity (%c). Valid values are n, e, o", c);
         parity = 0;
     }
 
@@ -315,7 +323,7 @@ parse_stopbits (guint i)
         stopbits = CSTOPB;
         break;
     default:
-        g_warning ("Invalid stop bits (%d). Valid values are 1 and 2)", i);
+        mm_warn ("Invalid stop bits (%d). Valid values are 1 and 2)", i);
         stopbits = 0;
     }
 
@@ -339,10 +347,9 @@ real_config_fd (MMSerialPort *self, int fd, GError **error)
 
     memset (&stbuf, 0, sizeof (struct termios));
     if (tcgetattr (fd, &stbuf) != 0) {
-        g_warning ("%s (%s): tcgetattr() error: %d",
-                   __func__,
-                   mm_port_get_device (MM_PORT (self)),
-                   errno);
+        mm_warn ("(%s): tcgetattr() error: %d",
+                 mm_port_get_device (MM_PORT (self)),
+                 errno);
     }
 
     stbuf.c_iflag &= ~(IGNCR | ICRNL | IUCLC | INPCK | IXON | IXANY );
@@ -365,8 +372,8 @@ real_config_fd (MMSerialPort *self, int fd, GError **error)
     errno = 0;
     if (cfsetispeed (&stbuf, speed) != 0) {
         g_set_error (error,
-                     MM_MODEM_ERROR,
-                     MM_MODEM_ERROR_GENERAL,
+                     MM_CORE_ERROR,
+                     MM_CORE_ERROR_FAILED,
                      "%s: failed to set serial port input speed; errno %d",
                      __func__, errno);
         return FALSE;
@@ -375,8 +382,8 @@ real_config_fd (MMSerialPort *self, int fd, GError **error)
     errno = 0;
     if (cfsetospeed (&stbuf, speed) != 0) {
         g_set_error (error,
-                     MM_MODEM_ERROR,
-                     MM_MODEM_ERROR_GENERAL,
+                     MM_CORE_ERROR,
+                     MM_CORE_ERROR_FAILED,
                      "%s: failed to set serial port output speed; errno %d",
                      __func__, errno);
         return FALSE;
@@ -384,8 +391,8 @@ real_config_fd (MMSerialPort *self, int fd, GError **error)
 
     if (tcsetattr (fd, TCSANOW, &stbuf) < 0) {
         g_set_error (error,
-                     MM_MODEM_ERROR,
-                     MM_MODEM_ERROR_GENERAL,
+                     MM_CORE_ERROR,
+                     MM_CORE_ERROR_FAILED,
                      "%s: failed to set serial port attributes; errno %d",
                      __func__, errno);
         return FALSE;
@@ -561,6 +568,15 @@ mm_serial_port_got_response (MMSerialPort *self, GError *error)
         priv->timeout_id = 0;
     }
 
+    if (priv->cancellable_id) {
+        g_assert (priv->cancellable != NULL);
+        g_cancellable_disconnect (priv->cancellable,
+                                  priv->cancellable_id);
+        priv->cancellable_id = 0;
+    }
+
+    g_clear_object (&priv->cancellable);
+
     info = (MMQueueData *) g_queue_pop_head (priv->queue);
     if (info) {
         if (info->cached && !error)
@@ -575,6 +591,7 @@ mm_serial_port_got_response (MMSerialPort *self, GError *error)
                                                                          info->user_data);
         }
 
+        g_clear_object (&info->cancellable);
         g_byte_array_free (info->command, TRUE);
         g_slice_free (MMQueueData, info);
     }
@@ -616,6 +633,26 @@ mm_serial_port_timed_out (gpointer data)
     return FALSE;
 }
 
+static void
+serial_port_response_wait_cancelled (GCancellable *cancellable,
+                                     MMSerialPort *self)
+{
+    MMSerialPortPrivate *priv = MM_SERIAL_PORT_GET_PRIVATE (self);
+    GError *error;
+
+    /* We don't want to call disconnect () while in the signal handler */
+    priv->cancellable_id = 0;
+
+    error = g_error_new_literal (MM_CORE_ERROR,
+                                 MM_CORE_ERROR_CANCELLED,
+                                 "Waiting for the reply cancelled");
+
+    /* FIXME: This is not completely correct - if the response finally arrives and there's
+       some other command waiting for response right now, the other command will
+       get the output of the cancelled command. Not sure what to do here. */
+    mm_serial_port_got_response (self, error);
+}
+
 static gboolean
 mm_serial_port_queue_process (gpointer data)
 {
@@ -637,11 +674,10 @@ mm_serial_port_queue_process (gpointer data)
             /* Ensure the response array is fully empty before setting the
              * cached response.  */
             if (priv->response->len > 0) {
-                g_warning ("%s: (%s) response array is not empty when using "
-                           "cached reply, cleaning up %u bytes",
-                           __func__,
-                           mm_port_get_device (MM_PORT (self)),
-                           priv->response->len);
+                mm_warn ("(%s) response array is not empty when using cached "
+                         "reply, cleaning up %u bytes",
+                         mm_port_get_device (MM_PORT (self)),
+                         priv->response->len);
                 g_byte_array_set_size (priv->response, 0);
             }
 
@@ -653,6 +689,23 @@ mm_serial_port_queue_process (gpointer data)
 
     if (mm_serial_port_process_command (self, info, &error)) {
         if (info->done) {
+            /* setup the cancellable so that we can stop waiting for a response */
+            if (info->cancellable) {
+                priv->cancellable = g_object_ref (info->cancellable);
+                priv->cancellable_id = (g_cancellable_connect (
+                                            info->cancellable,
+                                            (GCallback) serial_port_response_wait_cancelled,
+                                            self,
+                                            NULL));
+                if (!priv->cancellable_id) {
+                    error = g_error_new (MM_CORE_ERROR,
+                                         MM_CORE_ERROR_CANCELLED,
+                                         "Won't wait for the reply");
+                    mm_serial_port_got_response (self, error);
+                    return FALSE;
+                }
+            }
+
             /* If the command is finished being sent, schedule the timeout */
             priv->timeout_id = g_timeout_add_seconds (info->timeout,
                                                       mm_serial_port_timed_out,
@@ -716,25 +769,24 @@ data_available (GIOChannel *source,
     do {
         GError *err = NULL;
 
+        bytes_read = 0;
         status = g_io_channel_read_chars (source, buf, SERIAL_BUF_SIZE, &bytes_read, &err);
         if (status == G_IO_STATUS_ERROR) {
-            if (err && err->message)
-                g_warning ("%s", err->message);
+            if (err && err->message) {
+                mm_warn ("(%s): read error: %s",
+                         mm_port_get_device (MM_PORT (self)),
+                         err->message);
+            }
             g_clear_error (&err);
-
-            /* Serial port is closed; we're done */
-            if (priv->watch_id == 0)
-                break;
         }
 
         /* If no bytes read, just let g_io_channel wait for more data */
         if (bytes_read == 0)
             break;
 
-        if (bytes_read > 0) {
-            serial_debug (self, "<--", buf, bytes_read);
-            g_byte_array_append (priv->response, (const guint8 *) buf, bytes_read);
-        }
+        g_assert (bytes_read > 0);
+        serial_debug (self, "<--", buf, bytes_read);
+        g_byte_array_append (priv->response, (const guint8 *) buf, bytes_read);
 
         /* Make sure the response doesn't grow too long */
         if ((priv->response->len > SERIAL_BUF_SIZE) && priv->spew_control) {
@@ -748,32 +800,12 @@ data_available (GIOChannel *source,
             priv->n_consecutive_timeouts = 0;
             mm_serial_port_got_response (self, err);
         }
-    } while (bytes_read == SERIAL_BUF_SIZE || status == G_IO_STATUS_AGAIN);
+    } while (   (bytes_read == SERIAL_BUF_SIZE || status == G_IO_STATUS_AGAIN)
+             && (priv->watch_id > 0));
 
     return TRUE;
 }
 
-static void
-data_watch_enable (MMSerialPort *self, gboolean enable)
-{
-    MMSerialPortPrivate *priv = MM_SERIAL_PORT_GET_PRIVATE (self);
-
-    if (priv->watch_id) {
-        if (enable)
-            g_warn_if_fail (priv->watch_id == 0);
-
-        g_source_remove (priv->watch_id);
-        priv->watch_id = 0;
-    }
-
-    if (enable) {
-        g_return_if_fail (priv->channel != NULL);
-        priv->watch_id = g_io_add_watch (priv->channel,
-                                         G_IO_IN | G_IO_ERR | G_IO_HUP,
-                                         data_available, self);
-    }
-}
-
 static void
 port_connected (MMSerialPort *self, GParamSpec *pspec, gpointer user_data)
 {
@@ -790,20 +822,16 @@ port_connected (MMSerialPort *self, GParamSpec *pspec, gpointer user_data)
     connected = mm_port_get_connected (MM_PORT (self));
 
     if (ioctl (priv->fd, (connected ? TIOCNXCL : TIOCEXCL)) < 0) {
-        g_warning ("%s: (%s) could not %s serial port lock: (%d) %s",
-                   __func__,
-                   mm_port_get_device (MM_PORT (self)),
-                   connected ? "drop" : "re-acquire",
-                   errno,
-                   strerror (errno));
+        mm_warn ("(%s): could not %s serial port lock: (%d) %s",
+                 mm_port_get_device (MM_PORT (self)),
+                 connected ? "drop" : "re-acquire",
+                 errno,
+                 strerror (errno));
         if (!connected) {
             // FIXME: do something here, maybe try again in a few seconds or
             // close the port and error out?
         }
     }
-
-    /* When connected ignore let PPP have all the data */
-    data_watch_enable (self, !connected);
 }
 
 gboolean
@@ -885,7 +913,9 @@ mm_serial_port_open (MMSerialPort *self, GError **error)
 
     priv->channel = g_io_channel_unix_new (priv->fd);
     g_io_channel_set_encoding (priv->channel, NULL, NULL);
-    data_watch_enable (self, TRUE);
+    priv->watch_id = g_io_add_watch (priv->channel,
+                                     G_IO_IN | G_IO_ERR | G_IO_HUP,
+                                     data_available, self);
 
     g_warn_if_fail (priv->connected_id == 0);
     priv->connected_id = g_signal_connect (self, "notify::" MM_PORT_CONNECTED,
@@ -921,6 +951,12 @@ mm_serial_port_close (MMSerialPort *self)
     g_return_if_fail (MM_IS_SERIAL_PORT (self));
 
     priv = MM_SERIAL_PORT_GET_PRIVATE (self);
+
+    /* If we forced closing the port, open_count will be 0 already.
+     * Just return without issuing any warning */
+    if (priv->forced_close)
+        return;
+
     g_return_if_fail (priv->open_count > 0);
 
     device = mm_port_get_device (MM_PORT (self));
@@ -961,7 +997,8 @@ mm_serial_port_close (MMSerialPort *self)
         g_get_current_time (&tv_start);
 
         if (priv->channel) {
-            data_watch_enable (self, FALSE);
+            g_source_remove (priv->watch_id);
+            priv->watch_id = 0;
             g_io_channel_shutdown (priv->channel, TRUE, NULL);
             g_io_channel_unref (priv->channel);
             priv->channel = NULL;
@@ -1009,6 +1046,7 @@ mm_serial_port_close (MMSerialPort *self)
             g_byte_array_free (response, TRUE);
         }
 
+        g_clear_object (&item->cancellable);
         g_byte_array_free (item->command, TRUE);
         g_slice_free (MMQueueData, item);
     }
@@ -1023,9 +1061,11 @@ mm_serial_port_close (MMSerialPort *self)
         g_source_remove (priv->queue_id);
         priv->queue_id = 0;
     }
+
+    g_clear_object (&priv->cancellable);
 }
 
-void
+static void
 mm_serial_port_close_force (MMSerialPort *self)
 {
     MMSerialPortPrivate *priv;
@@ -1034,11 +1074,25 @@ mm_serial_port_close_force (MMSerialPort *self)
     g_return_if_fail (MM_IS_SERIAL_PORT (self));
 
     priv = MM_SERIAL_PORT_GET_PRIVATE (self);
-    g_return_if_fail (priv->open_count > 0);
+
+    /* If already forced to close, return */
+    if (priv->forced_close)
+        return;
+
+    mm_info ("(%s) forced to close port",
+             mm_port_get_device (MM_PORT (self)));
+
+    /* If already closed, done */
+    if (!priv->open_count)
+        return;
 
     /* Force the port to close */
     priv->open_count = 1;
     mm_serial_port_close (self);
+
+    /* Mark as having forced the close, so that we don't warn about incorrect
+     * open counts */
+    priv->forced_close = TRUE;
 }
 
 static void
@@ -1047,6 +1101,7 @@ internal_queue_command (MMSerialPort *self,
                         gboolean take_command,
                         gboolean cached,
                         guint32 timeout_seconds,
+                        GCancellable *cancellable,
                         MMSerialResponseFn callback,
                         gpointer user_data)
 {
@@ -1082,6 +1137,7 @@ internal_queue_command (MMSerialPort *self,
 
     info->cached = cached;
     info->timeout = timeout_seconds;
+    info->cancellable = (cancellable ? g_object_ref (cancellable) : NULL);
     info->callback = (GCallback) callback;
     info->user_data = user_data;
 
@@ -1100,10 +1156,11 @@ mm_serial_port_queue_command (MMSerialPort *self,
                               GByteArray *command,
                               gboolean take_command,
                               guint32 timeout_seconds,
+                              GCancellable *cancellable,
                               MMSerialResponseFn callback,
                               gpointer user_data)
 {
-    internal_queue_command (self, command, take_command, FALSE, timeout_seconds, callback, user_data);
+    internal_queue_command (self, command, take_command, FALSE, timeout_seconds, cancellable, callback, user_data);
 }
 
 void
@@ -1111,10 +1168,11 @@ mm_serial_port_queue_command_cached (MMSerialPort *self,
                                      GByteArray *command,
                                      gboolean take_command,
                                      guint32 timeout_seconds,
+                                     GCancellable *cancellable,
                                      MMSerialResponseFn callback,
                                      gpointer user_data)
 {
-    internal_queue_command (self, command, take_command, TRUE, timeout_seconds, callback, user_data);
+    internal_queue_command (self, command, take_command, TRUE, timeout_seconds, cancellable, callback, user_data);
 }
 
 static gboolean
@@ -1125,8 +1183,8 @@ get_speed (MMSerialPort *self, speed_t *speed, GError **error)
     memset (&options, 0, sizeof (struct termios));
     if (tcgetattr (MM_SERIAL_PORT_GET_PRIVATE (self)->fd, &options) != 0) {
         g_set_error (error,
-                     MM_MODEM_ERROR,
-                     MM_MODEM_ERROR_GENERAL,
+                     MM_CORE_ERROR,
+                     MM_CORE_ERROR_FAILED,
                      "%s: tcgetattr() error %d",
                      __func__, errno);
         return FALSE;
@@ -1149,8 +1207,8 @@ set_speed (MMSerialPort *self, speed_t speed, GError **error)
     memset (&options, 0, sizeof (struct termios));
     if (tcgetattr (fd, &options) != 0) {
         g_set_error (error,
-                     MM_MODEM_ERROR,
-                     MM_MODEM_ERROR_GENERAL,
+                     MM_CORE_ERROR,
+                     MM_CORE_ERROR_FAILED,
                      "%s: tcgetattr() error %d",
                      __func__, errno);
         return FALSE;
@@ -1176,8 +1234,8 @@ set_speed (MMSerialPort *self, speed_t speed, GError **error)
         else {
             /* If not EAGAIN, hard error */
             g_set_error (error,
-                            MM_MODEM_ERROR,
-                            MM_MODEM_ERROR_GENERAL,
+                            MM_CORE_ERROR,
+                            MM_CORE_ERROR_FAILED,
                             "%s: tcsetattr() error %d",
                             __func__, errno);
             return FALSE;
@@ -1186,8 +1244,8 @@ set_speed (MMSerialPort *self, speed_t speed, GError **error)
 
     if (!success) {
         g_set_error (error,
-                        MM_MODEM_ERROR,
-                        MM_MODEM_ERROR_GENERAL,
+                        MM_CORE_ERROR,
+                        MM_CORE_ERROR_FAILED,
                         "%s: tcsetattr() retry timeout",
                         __func__);
         return FALSE;
@@ -1254,8 +1312,8 @@ mm_serial_port_flash (MMSerialPort *self,
     }
 
     if (priv->flash_id > 0) {
-        error = g_error_new_literal (MM_MODEM_ERROR,
-                                     MM_MODEM_ERROR_OPERATION_IN_PROGRESS,
+        error = g_error_new_literal (MM_CORE_ERROR,
+                                     MM_CORE_ERROR_IN_PROGRESS,
                                      "Modem is already being flashed.");
         goto error;
     }
@@ -1484,8 +1542,7 @@ dispose (GObject *object)
         priv->timeout_id = 0;
     }
 
-    if (mm_serial_port_is_open (MM_SERIAL_PORT (object)))
-        mm_serial_port_close_force (MM_SERIAL_PORT (object));
+    mm_serial_port_close_force (MM_SERIAL_PORT (object));
 
     mm_serial_port_flash_cancel (MM_SERIAL_PORT (object));
 
@@ -1614,4 +1671,3 @@ mm_serial_port_class_init (MMSerialPortClass *klass)
                       g_cclosure_marshal_VOID__UINT,
 					  G_TYPE_NONE, 1, G_TYPE_UINT);
 }
-
