@@ -19,6 +19,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gio/gio.h>
 
 #include "mm-port.h"
 
@@ -116,8 +117,6 @@ gboolean mm_serial_port_open              (MMSerialPort *self,
 
 void     mm_serial_port_close             (MMSerialPort *self);
 
-void     mm_serial_port_close_force       (MMSerialPort *self);
-
 gboolean mm_serial_port_flash             (MMSerialPort *self,
                                            guint32 flash_time,
                                            gboolean ignore_errors,
@@ -132,6 +131,7 @@ void     mm_serial_port_queue_command     (MMSerialPort *self,
                                            GByteArray *command,
                                            gboolean take_command,
                                            guint32 timeout_seconds,
+                                           GCancellable *cancellable,
                                            MMSerialResponseFn callback,
                                            gpointer user_data);
 
@@ -139,8 +139,8 @@ void     mm_serial_port_queue_command_cached (MMSerialPort *self,
                                               GByteArray *command,
                                               gboolean take_command,
                                               guint32 timeout_seconds,
+                                              GCancellable *cancellable,
                                               MMSerialResponseFn callback,
                                               gpointer user_data);
 
 #endif /* MM_SERIAL_PORT_H */
-
